@@ -48,12 +48,23 @@ THREAD_REVERSE_GEOCODING = "modRanaReverseGeocoding"
 THREAD_LOCAL_SEARCH_GOOGLE = "modRanaLocalSearchGoogle"
 THREAD_ROUTING_ONLINE_GOOGLE = "modRanaRoutingOnlineGoogle"
 THREAD_ROUTING_OFFLINE_MONAV = "modRanaRoutingOfflineMonav"
+THREAD_GPSD_CONSUMER = "modRanaGPSDConsumer"
+# tile down-/loading
+THREAD_TILE_DOWNLOAD_MANAGER = "modRanaTileDownloadManager"
+THREAD_TILE_DOWNLOAD_WORKER = "modRanaTileDownloadWorker"
+THREAD_TILE_STORAGE_LOADER = "modRanaTileStorageLoader"
 
 THREAD_CONNECTIVITY_CHECK = "modRanaConnectivityCheck"
 THREAD_LOCATION_CHECK = "modRanaCurrentPositionCheck"
 
 THREAD_TESTING_PROVIDER = "modRanaTestingProvider"
 
+# thread pools
+THREAD_POOL_AUTOMATIC_TILE_DOWNLOAD = "automaticTileDownload"
+
+THREAD_POOL_BATCH_DOWNLOAD = "batchTileDownload"
+THREAD_POOL_BATCH_SIZE_CHECK = "batchTileSizeCheck"
+
 # device types
 DEVICE_TYPE_DESKTOP = 1
 DEVICE_TYPE_SMARTPHONE = 2
@@ -75,6 +86,10 @@ ROUTE_PEDESTRIAN = 1
 ROUTE_BIKE = 2
 ROUTE_CAR = 3
 
+# local search
+DEFAULT_LOCAL_SEARCH_RADIUS=10000  # in meters
+
 # API access
 GOOGLE_API_KEY = 'ABQIAAAAv84YYgTIjdezewgb8xl5_xTKlax5G-CAZlpGqFgXfh-jq3S0yRS6XLrXE9CkHPS6KDCig4gHvHK3lw'
+GOOGLE_PLACES_API_KEY = 'AIzaSyAUbkZEu97uzwbl9IA4DNEMLlPg_gPlNTw'
 GEONAMES_USERNAME = "modrana"
\ No newline at end of file
