@@ -31,9 +31,6 @@ from . import geonames
 from . import local_search
 from . import online_providers
 
-DEFAULT_GOOGLE_API_KEY = "ABQIAAAAv84YYgTIjdezewgb8xl5_xTKlax5G-CAZlpGqFgXfh-jq3S0yRS6XLrXE9CkHPS6KDCig4gHvHK3lw"
-
-
 def getModule(m, d, i):
     return OnlineServices(m, d, i)
 
@@ -96,13 +93,16 @@ class OnlineServices(RanaModule):
         """
         # we use the Google Local Search backend at the moment
         provider = online_providers.GoogleLocalSearch()
-        return provider.search(term=term, around=around, maxResults=maxResults)
+        radius = int(self.get("localSearchRadius", constants.DEFAULT_LOCAL_SEARCH_RADIUS))
+        return provider.search(term=term, around=around, maxResults=maxResults,
+                               radius=radius)
 
-    def localSearchAsync(self, term, callback, around=None, maxResults=8):
+    def localSearchAsync(self, term, callback, around=None, maxResults=20, sensor='false'):
         provider = online_providers.GoogleLocalSearch()
         # we use the Google Local Search backend at the moment
-        provider.searchAsync(callback, term=term, around=around, maxResults=maxResults)
-
+        radius = int(self.get("localSearchRadius", constants.DEFAULT_LOCAL_SEARCH_RADIUS))
+        provider.searchAsync(callback, term=term, around=around, maxResults=maxResults,
+                             sensor=sensor, radius=radius)
 
     # ** OSM static map URL **
 
